==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/report_task_br/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Report on tasks by user for projects',
    'version': '7.0.21.12.14',
    'category': 'Project',
    'description': """Gives statistics on tasks by user on projects to check the pipeline of users.""",
    'author': 'Tiny',
    'depends': ['project_br'],
    'data': ['security/ir.model.access.csv',
		           'views/task_br_project_view.xml',
		           'views/task_br_closed_board_view.xml',
		           'views/action.xml',
		           'views/menu.xml',
                  ],
    'installable': True,
    'active': False,
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/report_task_br/__openerp__.py <==
# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################


{
    'name': 'Report on tasks by user for projects',
    'version': '7.0.2310.2',
    'category': 'Project',
    'description': """Gives statistics on tasks by user on projects to check the pipeline of users.""",
    'author': 'Tiny',
    'depends': ['project_br'],
    'data': ['security/ir.model.access.csv',
		           'views/task_br_project_view.xml',
		           'views/task_br_closed_board_view.xml',
		           'views/action.xml',
		           'views/menu.xml',
                  ],
    'installable': True,
    'active': False,
}
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
